@@ -1,7 +1,7 @@
 package Carton;
 use strict;
 use 5.008_005;
-use version; our $VERSION = version->declare("v0.9.64");
+use version; our $VERSION = version->declare("v0.9.65");
 
 1;
 __END__
@@ -18,7 +18,7 @@ Carton - Perl module dependency manager (aka Bundler for Perl)
   requires 'Starman', 0.2000;
 
   > carton install
-  > git add cpanfile carton.lock
+  > git add cpanfile cpanfile.snapshot
   > git commit -m "add Plack and Starman"
 
   # Other developer's machine, or on a deployment box
@@ -36,7 +36,7 @@ HAVE BEEN WARNED.>
 
 carton is a command line tool to track the Perl module dependencies
 for your Perl application. The managed dependencies are tracked in a
-I<carton.lock> file, which is meant to be version controlled, and the
+I<cpanfile.snapshot> file, which is meant to be version controlled, and the
 lock file allows other developers of your application will have the
 exact same versions of the modules.
 
@@ -50,7 +50,7 @@ exclude these directories from the version control system.
 
   > echo .carton/ >> .gitignore
   > echo local/ >> .gitignore
-  > git add carton.lock
+  > git add cpanfile.snapshot
   > git commit -m "Start using carton"
 
 =head2 Tracking the dependencies
@@ -67,14 +67,14 @@ And then you can install these dependencies via:
 
 The modules are installed into your I<local> directory, and the
 dependencies tree and version information are analyzed and saved into
-I<carton.lock> in your directory.
+I<cpanfile.snapshot> in your directory.
 
-Make sure you add I<carton.lock> to your version controlled repository
+Make sure you add I<cpanfile.snapshot> to your version controlled repository
 and commit changes as you update dependencies. This will ensure that
 other developers on your app, as well as your deployment environment,
 use exactly the same versions of the modules you just installed.
 
-  > git add cpanfile carton.lock
+  > git add cpanfile cpanfile.snapshot
   > git commit -m "Added Plack and Starman"
 
 =head2 Deploying your application
@@ -85,7 +85,7 @@ I<.carton>) and run the following command:
 
   > carton install
 
-This will look at the I<carton.lock> and install the exact same
+This will look at the I<cpanfile.snapshot> and install the exact same
 versions of the dependencies into I<local>, and now your application
 is ready to run.
 
